@@ -2,6 +2,7 @@ import torch
 import numpy as np
 import pickle
 import os
+import SimpleITK as sitk
 import torch.nn.functional as F
 
 class Normalizer(object):
@@ -86,13 +87,36 @@ class Get_target_spacing(object):
         self.anisotropy_percentile_value = 0.90
         self.image_dimension = image_dimension
 
-    def run(self, dir_path):
+    def run(self, dir_path, dtype = 'pkl'):
+        """
+        type은 pkl 또는 nifti
+        """
         for file_name in os.listdir(dir_path):
-            if file_name[-3:] == 'pkl':
-                path = os.path.join(dir_path, file_name)
-                file = open(path, 'rb')
-                self.append(pickle.load(file)['spacing'])
-                file.close()
+            if dtype == 'pkl':
+                if file_name[-3:] == 'pkl':
+                    path = os.path.join(dir_path, file_name)
+                    file = open(path, 'rb')
+                    self.append(pickle.load(file)['spacing'])
+                    file.close()
+            
+            if dtype == 'nifti':
+                if 'nii' in file_name:
+                    path = os.path.join(dir_path, file_name)
+                    img = sitk.ReadImage(path)
+                    spacing = img.GetSpacing()
+                    self.append(spacing)
+    
+    def run_file_path(self, file_path):
+        if type == 'pkl':
+                if file_path[-3:] == 'pkl':
+                    file = open(file_path, 'rb')
+                    self.append(pickle.load(file)['spacing'])
+                    file.close()
+        if type == 'nifti':
+            if 'nii' in file_path:
+                img = sitk.ReadImage(file_path)
+                spacing = img.GetSpacing()
+                self.append(spacing)
     
     def reset(self):
         self.spaces = None
@@ -117,4 +141,5 @@ class Get_target_spacing(object):
     
     def is_anisotropy(self):
         return np.where((np.max(self.spaces, axis = 0) / np.min(self.spaces, axis = 0)) > self.anisotropy_threshold)[0].astype(int)
-    
\ No newline at end of file
+    
+
